@@ -34,19 +34,11 @@
 #include <spice/types.h>
 
 #if    __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 96)
-#define SPICE_GNUC_PURE __attribute__((__pure__))
 #define SPICE_GNUC_MALLOC __attribute__((__malloc__))
 #else
-#define SPICE_GNUC_PURE
 #define SPICE_GNUC_MALLOC
 #endif
 
-#if     __GNUC__ >= 4
-#define SPICE_GNUC_NULL_TERMINATED __attribute__((__sentinel__))
-#else
-#define SPICE_GNUC_NULL_TERMINATED
-#endif
-
 #ifndef __has_feature
 #define __has_feature(x) 0  /* Compatibility with non-clang compilers. */
 #endif
@@ -62,20 +54,12 @@
 
 #if     __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
 #define SPICE_GNUC_PRINTF( format_idx, arg_idx ) __attribute__((__format__ (__printf__, format_idx, arg_idx)))
-#define SPICE_GNUC_SCANF( format_idx, arg_idx ) __attribute__((__format__ (__scanf__, format_idx, arg_idx)))
-#define SPICE_GNUC_FORMAT( arg_idx ) __attribute__((__format_arg__ (arg_idx)))
 #define SPICE_GNUC_NORETURN __attribute__((__noreturn__))
-#define SPICE_GNUC_CONST __attribute__((__const__))
 #define SPICE_GNUC_UNUSED __attribute__((__unused__))
-#define SPICE_GNUC_NO_INSTRUMENT __attribute__((__no_instrument_function__))
 #else   /* !__GNUC__ */
 #define SPICE_GNUC_PRINTF( format_idx, arg_idx )
-#define SPICE_GNUC_SCANF( format_idx, arg_idx )
-#define SPICE_GNUC_FORMAT( arg_idx )
 #define SPICE_GNUC_NORETURN
-#define SPICE_GNUC_CONST
 #define SPICE_GNUC_UNUSED
-#define SPICE_GNUC_NO_INSTRUMENT
 #endif  /* !__GNUC__ */
 
 #ifdef G_DEPRECATED
@@ -248,7 +232,7 @@
 
 /* Arch specific stuff for speed
  */
-#if defined (__GNUC__) && (__GNUC__ >= 4) && defined (__OPTIMIZE__)
+#if (defined(__clang__) || defined (__GNUC__) && __GNUC__ >= 4 && __GNUC_MINOR__ >= 5) && defined (__OPTIMIZE__)
 #  define SPICE_BYTESWAP16(val) __builtin_bswap16(val)
 #  define SPICE_BYTESWAP32(val) __builtin_bswap32(val)
 #  define SPICE_BYTESWAP64(val) __builtin_bswap64(val)
